#!/bin/bash
#
# source: http://hal.freedesktop.org/releases/hal-info-20091130.tar.bz2
#
# maintainer: gmg (monpntet.gerard@neuf.fr)
#

#------------------Set Some Variables

soft="hal-info"
softversion="20091130"
arch="noarch"
cpu="i686"
packageversion="64.1"

buildir=$(pwd)
srcpkg="$buildir/$soft-$softversion.tar.bz2"
src="$buildir/$soft-$softversion"
package="$soft-$softversion-$arch-$packageversion"
dest="$buildir/$package"

# -----------------Extract sources and get ready to build

cd $buildir
rm -rf $src
tar -xvjf $srcpkg
rm -f $dest.tgz
rm -rf $dest

#------------------Set correct permissions

cd $src

chown -R root:root .
find . \
 \( -perm 777 -o -perm 775 -o -perm 711 -o -perm 555 -o -perm 511 \) \
 -exec chmod 755 {} \; -o \
 \( -perm 666 -o -perm 664 -o -perm 600 -o -perm 444 -o -perm 440 -o -perm 400 \) \
 -exec chmod 644 {} \;

#------------------Start Configure

./configure \
 --prefix=/usr \
 --sysconfdir=/etc

make
make install DESTDIR=$dest

#-------------------Prepare the documentation:

mkdir -p $dest/usr/doc/$soft-$softversion
cp -a AUTHORS COPYING HACKING INSTALL NEWS README $dest/usr/doc/$soft-$softversion

mkdir -p $dest/install
cat << EODESC > $dest/install/slack-desc
# HOW TO EDIT THIS FILE:
# The "handy ruler" below makes it easier to edit a package description.  Line
# up the first '|' above the ':' following the base package name, and the '|'
# on the right side marks the last column you can put a character in.  You must
# make exactly 11 lines for the formatting to be correct.  It's also
# customary to leave one space after the ':'.

        |-----handy-ruler------------------------------------------------------|
hal-info: hal-info (device information for HAL)
hal-info:
hal-info: The hal-info package contains device information for HAL, a Hardware
hal-info: Abstraction Layer.
hal-info:
hal-info: For more info, see:  http://www.freedesktop.org/Software/hal
hal-info:
hal-info:
hal-info:
hal-info:
hal-info:
EODESC


mkdir -p $dest/usr/src/$soft-$softversion
cp -a $buildir/build-$soft.sh $dest/usr/src/$soft-$softversion

#-------------------Make the packages and the md5sum

cd $dest
makepkg -l y -c n $dest.txz
makepkg -l y -c n $dest.tgz
cd $buildir
md5sum $package.txz > $package.md5